Clear local polio data cache
clear_local_polio_data_cache.RdThe local polio cache is created when get_all_polio_data() is called with
local_caching = TRUE. The function clears the cache by deleting all the files within it.

clear_local_polio_data_cache.RdThe local polio cache is created when get_all_polio_data() is called with
local_caching = TRUE. The function clears the cache by deleting all the files within it.