Skip to contents

The function is meant to be used for f.stool.ad.01(). This function will classify the adequacy of a stool sample based on timeliness and condition.

Usage

generate_ad_final_col(afp.data)

Arguments

afp.data

tibble AFP dataset. Either raw.data$afp from get_all_polio_data() or ctry.data$afp.all.2 from extract_country_data().

Value

tibble AFP dataset with adequacy.final column

Examples

if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data(attach.spatial.data = FALSE)
stool.data <- generate_ad_final_col(raw.data$afp)
} # }