Timeliness of arrival at sequencing lab to sequencing results
generate_lab_seqres_violin.RdShows the timeliness of arrival in the sequencing lab to sequencing results. The target is 7 days for cases shipped for sequencing.
Usage
generate_lab_seqres_violin(
lab_data,
afp_data,
start_date,
end_date,
priority_level = c("HIGH", "MEDIUM", "LOW (WATCHLIST)", "LOW"),
who_region = NULL,
rolling = TRUE,
output_path = Sys.getenv("KPI_FIGURES"),
y_max = NULL
)Arguments
- lab_data
tibbleGlobal lab dataset.- afp_data
tibbleAFP dataset.- start_date
strStart date of the analysis formatted as "YYYY-MM-DD".- end_date
strEnd date of the analysis formatted as "YYYY-MM-DD".- priority_level
listPriority levels to display. Defaults toc("HIGH", "MEDIUM", "LOW (WATCHLIST)", "LOW").- who_region
listRegions to display. Defaults toNULL, which shows all of the regions.- rolling
logicalUsing rolling periods or year-to-year? Defaults toTRUE.- output_path
strWhere to output the figure to.- y_max
numMaximum value in the y-axis.
Examples
if (FALSE) { # \dontrun{
raw_data <- get_all_polio_data()
lab_data <- edav_io("read", file_loc = get_constant("CLEANED_LAB_DATA"))
generate_lab_seqres_violin(lab_data, raw_data$afp,
"2021-01-01", "2023-12-31", getwd())
} # }