Determines whether lab data is EMRO or AFRO
get_region.RdOutputs the name of the region which a country belongs to.
Usage
get_region(country_name = Sys.getenv("DR_COUNTRY"))
get_region.RdOutputs the name of the region which a country belongs to.
get_region(country_name = Sys.getenv("DR_COUNTRY"))