Obtain available variables for VPD data
get_vpd_vars.Rdlifecycle::badge("experimental")
Obtains the variable names available for each vaccine preventable disease (VPD)
in the variable column.

get_vpd_vars.Rdlifecycle::badge("experimental")
Obtains the variable names available for each vaccine preventable disease (VPD)
in the variable column.