Download province geographic data
load_clean_prov_sp.RdPulls province shapefiles directly from the geodatabase
Usage
load_clean_prov_sp(
azcontainer = suppressMessages(get_azure_storage_connection()),
fp = "GID/PEB/SIR/Data/spatial/global.prov.rds",
prov_guid = NULL,
prov_name = NULL,
ctry_name = NULL,
end_year = lubridate::year(Sys.Date()),
st_year = 2000,
data_only = FALSE,
type = NULL,
version = "standard",
edav = TRUE,
end.year = lifecycle::deprecated(),
st.year = lifecycle::deprecated(),
data.only = lifecycle::deprecated()
)Arguments
- azcontainer
Azure validated container object
- fp
strLocation of geodatabase.- prov_guid
str arrayArray of all province GUIDS that you want to pull.- prov_name
str arrayArray of all province names that you want to pull.- ctry_name
str arrayArray of all country names that you want to pull.- end_year
intLast year you want to pull information for. Default is current year.- st_year
intEarlier year of spatial data you want to pull. Default is 2000.- data_only
logicalWhether to return a tibble with shapefiles or not. Defaults toFALSE.- type
strWhether to return a spatial object for every year group. Defaults toNULL."long"Return a dataset for every year group.NULLReturn a dataset only with unique GUIDs and when they were active.
- version
strSpecify whether to return standard shapefiles or new shapefiles still under evaluation/development. Default is"standard"."standard"Standard shapefiles."dev"New shapefiles still under evaluation/development.
- edav
logicalLoad from EDAV? Defaults toTRUE.- end.year
- st.year
- data.only
Examples
if (FALSE) { # \dontrun{
prov <- load_clean_prov_sp(ctry_name = c("ALGERIA", "NIGERIA"), st_year = 2019)
prov.long <- load_clean_prov_sp(ctry_name = "ALGERIA", st_year = 2019, type = "long")
} # }