Check GUIDs present in the AFP linelist but not in the pop files
check_afp_guid_ctry_data.RdThe function will run a check in the AFP linelist for GUIDs that are not part
of the spatial files. In these instances, typically, unknown GUIDs are part of the
new geodatabase from WHO that get released in the next updated geodatabase. Therefore,
this function should be used only if necessary. For example, in instances where mapping an AFP case into a
a district is critical and the shapefile from extract_country_data() is not yet updated.
Arguments
- ctry.data
listCountry polio data, with spatial data attached. Output ofextract_country_data()orinit_dr().
Examples
if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data() # must contain spatial data to run the function
ctry.data <- extract_country_data("algeria", raw.data)
error.list <- check_afp_guid_ctry_data(ctry.data)
} # }