Cleans and adds additional age and dosage number columns to the AFP linelist
clean_ctry_data.RdThe function does additional cleaning of the ctry.data list. It fills in
missing districts, convert character date columns to a date data type, calculates
age group, add columns for the number of doses per case, and cleans the environmental
surveillance data.
Arguments
- ctry.data
listLarge list containing polio country data. This is the output ofextract_country_data()orinit_dr().
Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
ctry.data <- clean_ctry_data(ctry.data)
} # }