Clean environmental surveillance data
clean_es_data.RdThe cleaning step will attempt to impute missing site coordinates and create standardized columns used in the desk review.
Usage
clean_es_data(es.data, dist.shape, ctry.data = lifecycle::deprecated())Examples
if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data(attach.spatial.data = FALSE)
ctry.data <- extract_country_data("algeria", raw.data)
ctry.data$es <- clean_es_data(ctry.data$es, ctry.data$dist)
} # }