Create the consequential geography expansion map
create_cg_expansion_map.RdCreates a map of consequential geographies.
Arguments
- polio_data
listOutput ofget_all_polio_data()withattach.spatial.data = TRUE.- cg
tibbleTable containing data about existing CGs, the dataset is expected to contain the following headers of the following datatypes:type:strConsequential geographies must have a type of"cg". All other can beNA.label:strGeographic grouping (i.e., "Lake Chad"). Can be a country or a subset of a country (i.e., "Northern Yemen"). This column will be used to group the consequential geographies for creating super regions.ctry:strName of the country.prov:strName of the province.dist:strName of the district.adm_level:strName of the administrative level. Must be one ofNAif at the country level,"adm1"if at the province level, and"adm2if at the district level.
Details
You can download an example dataset using: sirfunctions_io("read", file_loc = "Data/misc/consequential_geographies.rds").
Examples
if (FALSE) { # \dontrun{
polio_data <- get_all_polio_data()
cg <- sirfunctions_io("read", file_loc = "Data/misc/consequential_geographies.rds")
create_cg_expansion_map(polio_data, cg)
} # }