Export stool adequacy data
create_stool_adequacy_export.RdThe function combines the stool adequacy summary tables from f.stool.ad.01()
and exports to an Excel file, with each geographic level on its own tab.
Usage
create_stool_adequacy_export(
cstool,
pstool,
dstool,
excel_output_path = Sys.getenv("DR_TABLE_PATH")
)Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
cstool <- f.stool.ad.01(
ctry.data$afp.all.2, ctry.data$ctry.pop,
"2021-01-01", "2023-01-01", "ctry"
)
pstool <- f.stool.ad.01(
ctry.data$afp.all.2, ctry.data$prov.pop,
"2021-01-01", "2023-01-01", "prov"
)
dstool <- f.stool.ad.01(
ctry.data$afp.all.2, ctry.data$dist.pop,
"2021-01-01", "2023-01-01", "dist"
)
create_stool_adequacy_export(cstool, pstool, dstool)
} # }