Interactive loading of EDAV data
explore_edav.RdThis function is a way to interactively work with files in the EDAV environment, which is convenient as we don't have to search for files within Azure Storage Explorer.
Usage
explore_edav(
path = get_constant("DEFAULT_EDAV_FOLDER"),
azcontainer = suppressMessages(get_azure_storage_connection())
)Arguments
- path
strPath to start at initially.- azcontainer
Azure storage container provided by
get_azure_storage_connection().
Details
There are Excel files that may need additional formatting before it can be
read properly into an R object. For example, skipping columns or rows.
For complicated Excel files, it would be best to directly call edav_io()
in "read" mode, and pass additional parameters via .... See edav_io()
examples for details.