Calculate non-polio AFP rate
f.npafp.rate.01.RdCalculate the NPAFP rate from POLIS data. Can either pass raw.data to calculate NPAFP rates
on the global dataset, or a ctry.data dataset.
Usage
f.npafp.rate.01(
afp.data,
pop.data,
start.date,
end.date,
spatial.scale,
pending = T,
missing_agemonths = F,
rolling = F,
sp_continuity_validation = T
)Arguments
- afp.data
tibbleAFP data which includes GUID at a given spatial scale formatted asadm(0,1,2)guid, onset date asdateandcdc.classification.all2which includes"NPAFP", "PENDING", "LAB PENDING". This is eitherctry.data$afp.all.2ofextract_country_data()orinit_dr()orraw.data$afpofget_all_polio_data().- pop.data
tibbleUnder 15 population data by a given spatial scale includingyear,adm(0,1,2)guid,u15pop, andctry/prov/distas appropriate. This is part of the output ofget_all_polio_data()andextract_country_data().- start.date
strStart date with the format"YYYY-MM-DD".- end.date
strStart date with the format"YYYY-MM-DD".- spatial.scale
strSpatial scale for analysis."prov"Province level."dist"District level."ctry"Country level.
- pending
logicalShould cases classified asPENDINGorLAB PENDINGbe included in calculations? DefaultTRUE.- missing_agemonths
logicalShould cases withNAvalues forage.monthsbe included? DefaultFALSE.- rolling
logicalShould the analysis be performed on a rolling bases? DefaultFALSE.- sp_continuity_validation
logicalShould we filter places that are not present for the entirety of the analysis dates? DefaultTRUE.
Value
tibble A table containing NPAFP rates as well as additional information relevant to each location analyzed.
Examples
if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data()
npafp_ctry <- f.npafp.rate.01(raw.data$afp, raw.data$ctry.pop, "2022-01-01", "2024-12-31", "ctry")
} # }