Function to calculate timeliness of detection
f.timely.detection.01.RdCalculates the overall timeliness of detection in AFP & ES POLIS data.
Arguments
- afp.data
tibbleAFP data which includes classification of AFP cases with onset date and date of notification to HQ.- es.data
tibbleES data which includes classification of samples with collection date and date of notification to HQ.- ctryseq.data
tibbleA table consisting of the following columns for each country:With sequencing capacity within or outside of the country
Country (
ADM0_NAME)Classification of AFP cases & ES samples
Onset date of AFP cases and collection date of ES samples
Date of notification to HQ (
date.notification.to.hq)
This table is the output of
get_lab_locs().- start.date
strStart date for evaluation with format"YYYY-MM-DD".- end.date
strEnd date for evaluation with format"YYYY-MM-DD".- rolling
logicalShould timeliness be calculated in a rolling basis? DefaultFALSE.
Value
list A list with two tibbles with global and sub-global
AFP / ES detection timeliness evaluation.
Examples
if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data()
ctry.data <- extract_country_data("algeria", raw.data)
ctry.seq <- get_lab_locs()
global.summary <- f.timely.detection.01(
raw.data$afp, raw.data$es, ctry.seq,
"2021-01-01", "2023-12-31"
)
ctry.summary <- f.timely.detection.01(
ctry.data$afp.all.2, ctry.data$es, ctry.seq,
"2021-01-01", "2023-12-31"
)
} # }