Flag positives data from identified consequential geographies
flag_cg_positives.RdObtains positive detections and determines whether they are part of the
consequential geographies or not. If they are, then they are flagged in the column in_cg as
TRUE.
Arguments
- cg_super_regions
sfSpatial object of all CG super regions and a flag for all their specific GUIDs. This is the output ofcreate_cg_super_regions().- pos
tibbleThe positives file from the output ofget_all_polio_data().- start_year
intThe the earliest year for analysis. Defaults to 2016.
Examples
if (FALSE) { # \dontrun{
polio_data <- get_all_polio_data()
cg <- sirfunctions_io("read", file_loc = "Data/misc/consequential_geographies.rds")
super_regions <- create_cg_super_regions(cg,
ctry = polio_data$global.ctry, prov = polio_data$global.prov, dist = polio_data$global.dist)
cg_positives <- flag_cg_positives(cg_super_regions, polio_data$pos)
} # }