Helper function to add the adequacy.final column
generate_ad_final_col.RdThe function is meant to be used for f.stool.ad.01(). This function will
classify the adequacy of a stool sample based on timeliness and condition.
Arguments
- afp.data
tibbleAFP dataset. Eitherraw.data$afpfromget_all_polio_data()orctry.data$afp.all.2fromextract_country_data().
Examples
if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data(attach.spatial.data = FALSE)
stool.data <- generate_ad_final_col(raw.data$afp)
} # }