Generate C1 rollup for high-priority countries
generate_c1_rollup.RdGenerates a summary of how many of the high priority countries have met their AFP and ES indicators.
Usage
generate_c1_rollup(
c1,
priority_level = "HIGH",
who_region = NULL,
.group_by = "rolling_period",
npafp_target = 80,
stool_target = 80,
ev_target = 80,
timely_wpv_vdpv_target = 80
)Arguments
- c1
tibbleThe output ofgenerate_c1_table().- priority_level
str or listPriority level. Defaults to"HIGH". Valid values are"LOW", "LOW (WATCHLIST)", "MEDIUM", "HIGH"- who_region
strWHO region to summarize the data to.- .group_by
strHow the rollup should be grouped. Defaults to the column"rolling_period".- npafp_target
numTarget used when calculating the proportion of districts in a country that meets NPAFP rate.- stool_target
numTarget used when calculating the proportion of districts in a country that meets stool adequacy rate.- ev_target
numTarget used when calculating the proportion of ES sites in a country that meets EV detection rate.- timely_wpv_vdpv_target
numTarget used when calculating the proportion of ES sites in a country that meets timeliness of detection of WPV and VDPV cases.
Examples
if (FALSE) { # \dontrun{
raw_data <- get_all_polio_data()
c1 <- generate_c1_table(raw_data, "2022-01-01", "2024-12-31")
c1_rollup <- generate_c1_rollup(c1)
} # }