GPEI Strategy surveillance KPIs
generate_c1_table.RdMonitoring surveillance KPIs for Certification of Poliomyelitis Eradication at country regional and global levels.
Usage
generate_c1_table(
raw_data,
start_date,
end_date,
risk_category = NULL,
risk_table = NULL,
lab_locs = NULL
)Arguments
- raw_data
listGlobal polio surveillance dataset. Output ofget_all_polio_data().- start_date
strStart date of the analysis in YYYY-MM-DD format.- end_date
strEnd date of the analysis in YYYY-MM-DD format.- risk_category
strRisk category or a list of categories. Defaults toNULL. Valid values are:"LOW, LOW (WATCHLIST), MEDIUM, HIGH.- risk_table
tibblePriority level of each country. Defaults toNULL, which will download the information directly from EDAV.- lab_locs
tibbleSummary of the sequencing capacities of labs. Output ofget_lab_locs(). Defaults toNULL, which will download the information directly from EDAV. .
Examples
if (FALSE) { # \dontrun{
raw_data <- get_all_polio_data(attach.spatial.data = FALSE)
c1 <- generate_c1_table(raw_data, "2021-01-01", "2023-12-31")
} # }