Immunization rates per year
generate_case_num_dose_g.RdGenerates a stacked percent bar plot displaying immunization rates per year for the country. Note that this function only graphs immunization rates for children aged 6-59 months that have the classification of NPAFP.
Usage
generate_case_num_dose_g(
ctry.data,
start_date,
end_date,
output_path = Sys.getenv("DR_FIGURE_PATH")
)Arguments
- ctry.data
listA large list containing polio data of country. This is the output ofextract_country_data()orinit_dr(). Note thatctry_dataneeds to be cleaned viaclean_ctry_data()prior to running the function.- start_date
strStart date of analysis.- end_date
strEnd date of analysis.- output_path
strLocal path of where to save the figure to.
Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
ctry.data <- clean_ctry_data(ctry.data)
generate_case_num_dose_g(ctry.data, "2021-01-01", "2023-12-31")
} # }