Generate the desk review slide deck
generate_dr_ppt.RdThe original function to build the desk review PowerPoint. This function has been
superseded by generate_dr_ppt2(). The function outputs images to the PowerPoint
directly from objects, unlike generate_dr_ppt2() which uses images saved in a folder.
Usage
generate_dr_ppt(
ctry.data,
start_date,
end_date,
pop.map,
pop.map.prov,
afp.case.map,
afp.epi.curve,
surv.ind.tab,
afp.dets.prov.year,
pop.tab,
npafp.map,
npafp.map.dist,
stool.ad.maps,
stool.ad.maps.dist,
inad.tab.flex,
tab.60d,
case.num.dose.g,
timely_nation,
timely_prov,
mapt_all,
es.site.det,
es.det.map,
es.timely,
es.table,
country = Sys.getenv("DR_COUNTRY"),
ppt_template_path = NULL,
ppt_output_path = Sys.getenv("DR_POWERPOINT_PATH")
)Arguments
- ctry.data
listList containing polio data for a country. Either the output ofextract_country_data()orinit_dr().- start_date
strStart date of desk review.- end_date
strEnd date of desk review.- pop.map
ggplotCountry pop map.- pop.map.prov
ggplotProv pop map.- afp.case.map
ggplotMap of afp cases.- afp.epi.curve
ggplotAFP epicurve.- surv.ind.tab
flextableSurveillance indicator table.- afp.dets.prov.year
ggplotAFP detections for province.- pop.tab
flextableTable of population.- npafp.map
ggplotNPAFP map for country level.- npafp.map.dist
ggplotNPAFP map for district level.- stool.ad.maps
ggplotStool adequacy maps at province.- stool.ad.maps.dist
ggplotStool adequacy maps at district.- inad.tab.flex
flextableInadequate table.- tab.60d
flextable60-day follow-up table.- case.num.dose.g
ggplotImmunization rates per year.- timely_nation
ggplotTimeliness at country level.- timely_prov
ggplotTimeliness at province level.- mapt_all
ggplotMap with all indicators.- es.site.det
ggplotES site viral detection.- es.det.map
ggplotES site detection maps.- es.timely
ggplotES timeliness.- es.table
flextableES table.- country
strName of the country.- ppt_template_path
strPath to the PowerPoint template.- ppt_output_path
strPath where the PowerPoint should be outputted.
Examples
if (FALSE) { # \dontrun{
# Assume all figures and tables are assigned to the appropriate variable.
template_path <- "C:/Users/ABC1/Desktop/deskreview_template.pptx"
generate_dr_ppt(
template_path, ctry.data, start_date, end_date, pop.map,
pop.map, pop.map.prov, afp.case.map, afp.epi.curve,
surv.ind.tab, afp.dets.prov.year, pop.tab, npafp.map,
npafp.map.dist, stool.ad.maps, stool.ad.maps.dist,
inad.tab.flex, tab.60d, case.num.dose.g,
timely_nation, timely_prov,
mapt_all, es.site.det, es.det.map, es.timely,
es.table
)
} # }