Generate the desk review slide deck from the figures folder
generate_dr_ppt2.RdGenerating the PowerPoint from the figures folder is generally faster and allows figures to remain consistent. Tables remain as PowerPoint tables.
Usage
generate_dr_ppt2(
ctry.data,
start_date,
end_date,
surv.ind.tab,
inad.tab.flex,
tab.60d,
pop.tab,
es.table,
ppt_template_path = NULL,
fig.path = Sys.getenv("DR_FIGURE_PATH"),
country = Sys.getenv("DR_COUNTRY"),
ppt_output_path = Sys.getenv("DR_POWERPOINT_PATH")
)Arguments
- ctry.data
listCountry polio data. Either the output ofextract_country_data()orinit_dr().- start_date
strStart date of desk review.- end_date
strEnd date of desk review.- surv.ind.tab
flextableSurveillance indicator table- inad.tab.flex
flextableInadequates table.- tab.60d
flextable60-day follow-up table.- pop.tab
flextablePopulation table.- es.table
flextableES table.- ppt_template_path
strPath to the PowerPoint template.- fig.path
strFile path to the figures folder.- country
strName of the country.- ppt_output_path
strPath where the PowerPoint should be outputted.
Examples
if (FALSE) { # \dontrun{
# Assume all figures and tables are assigned to the appropriate variable.
ppt_template <- "C:/Users/ABC1/Desktop/deskreview_template.pptx"
generate_dr_ppt2(ctry.data, start_date, end_date,
surv.ind.tab, inad.tab.flex, tab.60d, es.table,
ppt_template_path = ppt_template
)
} # }