ES surveillance sites summary table
generate_es_tab.RdGenerates a summary table on the performance of surveillance sites over a rolling basis as indicated by the start and end dates. Includes information on the EV detection rate, number of samples collected, percentage of samples with good condition, and percentage of samples meeting the timeliness target of arriving to lab within 3 days.
Arguments
- es.data
tibbleES data. This isctry.data$es, which is part of the output of eitherextract_country_data()orinit_dr(). Ensure that thectry.dataobject has been cleaned withclean_ctry_data()first. Otherwise, there will be an error.- es_start_date
strStart date of analysis. Defaults to a year before the end date.- es_end_date
strEnd date of analysis.
Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
ctry.data <- clean_ctry_data(ctry.data)
generate_es_tab(ctry.data$es, es_end_date = "2023-12-31")
} # }