ES timeliness scatterplot
generate_es_timely.RdGenerates a scatterplot of the time it takes for each environmental samples to arrive in lab.
Usage
generate_es_timely(
es.data,
es_start_date = (lubridate::as_date(es_end_date) - lubridate::years(1)),
es_end_date = end_date,
output_path = Sys.getenv("DR_FIGURE_PATH"),
add_legend = TRUE,
.color = "site.name"
)Arguments
- es.data
tibbleES data.- es_start_date
strStart date of analysis. By default, this is one year from the end date.- es_end_date
strEnd date of analysis.- output_path
strLocal path for where to save the figure to.- add_legend
logicalWhether to add or remove a legend in the figure.- .color
strWhat column to use as color. Defaults tosite.name.
Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
generate_es_timely(ctry.data$es)
} # }