Generate a stool adequacy summary at the regional level
generate_inad_tab_region.RdGenerates a summary table at the country level highlighting issues around stool adequacy.
Arguments
- afp_data
tibbleafp.all.2of the output ofextract_country_data().- cstool
tibbleStool adequacy at the country level. This is the output off.stool.ad.01().- start_date
strStart date of analysis.- end_date
strEnd date of analysis.