Visits to health clinics per year
generate_iss_barplot.RdGenerates a bar plot showing the number of visits to health clinics per year using the ISS/eSURV data.
Usage
generate_iss_barplot(
iss.data = NULL,
start_date,
end_date,
output_path = Sys.getenv("DR_FIGURE_PATH")
)Arguments
- iss.data
tibbleISS/eSURV data that has been cleaned viaclean_iss_data().- start_date
strStart date of the analysis.- end_date
strEnd date of the analysis.- output_path
strLocal path where the figure is saved to.
Examples
if (FALSE) { # \dontrun{
iss_path <- "C:/Users/ABC1/Desktop/iss_data.csv"
ctry.data <- init_dr("algeria", iss_data_path = iss_path)
ctry.data$iss.data <- clean_iss_data(ctry.data)
generate_iss_barplot(ctry.data$iss.data)
} # }