Generate tile plots for indicators
generate_kpi_tile.RdGenerates tile plots for indicators present in c1-c4, showing changes over multiple rolling periods.
Usage
generate_kpi_tile(
c_table,
priority_category = "HIGH",
output_path = Sys.getenv("KPI_FIGURES")
)Details
The function automatically detects the geographic scale to present in each plot. If passing a table that is grouped lower than the country level, we recommend that only one country is present or a subset of districts are presented so that the output plot is legible.
Examples
if (FALSE) { # \dontrun{
raw_data <- get_all_polio_data()
c1 <- generate_c1_table(raw_data, "2021-01-01", "2023-12-31")
generate_kpi_tile(c1)
} # }