Summary table of indicators at the province level
generate_pop_tab.RdGenerates a table summarizing both NPAFP and stool adequacy rates at the province level and by year.
Usage
generate_pop_tab(
pnpafp,
pstool,
start_date,
end_date,
prov.case.ind = lifecycle::deprecated()
)Arguments
- pnpafp
tibbleNPAFP table. Output off.npafp.rate.01()at the province level.- pstool
tibbleStool adequacy at province level. Output off.stool.ad.01()at the province level.- start_date
strStart date of analysis.- end_date
strEnd date of analysis.- prov.case.ind
tibbleDeprecated in favor of the more informative pnpafp param name.
Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
start_date <- "2021-01-01"
end_date <- "2023-12-31"
prov.extract <- f.npafp.rate.01(
afp.data = ctry.data$afp.all.2,
pop.data = ctry.data$prov.pop,
start.date = start_date,
end.date = end_date,
spatial.scale = "prov",
pending = T,
rolling = F,
sp_continuity_validation = F
)
pstool <- f.stool.ad.01(
afp.data = ctry.data$afp.all.2,
admin.data = ctry.data$prov.pop,
start.date = start_date,
end.date = end_date,
spatial.scale = "prov",
missing = "good",
bad.data = "inadequate",
rolling = F,
sp_continuity_validation = F
)
generate_pop_tab(prov.extract, pstool, start_date, end_date)
} # }