Maps evaluating timeliness of samples against timeliness targets.
generate_timeliness_maps.RdGenerates a map at the provincial level summarizing the timeliness of samples across different timeliness targets. The figure is faceted by the type of timeliness target, with each facet containing the percentage of samples from each province that met the targets over the years.
Usage
generate_timeliness_maps(
ctry.data,
ctry.shape,
prov.shape,
start_date,
end_date,
mark_x = T,
pt_size = 4,
output_path = Sys.getenv("DR_FIGURE_PATH")
)Arguments
- ctry.data
listLarge list containing polio data for a country. This is the output ofextract_country_data()orinit_dr().- ctry.shape
sfCountry shapefile in long format.- prov.shape
sfProvince shapefile in long format.- start_date
strStart date of analysis.- end_date
strEnd date of analysis.- mark_x
logicalMark where there are less than 5 AFP cases? Defaults toTRUE.- pt_size
numericSize of the marks.- output_path
strLocal path where to save the figure to.
Examples
if (FALSE) { # \dontrun{
ctry.data <- init_dr("algeria")
ctry.shape <- load_clean_ctry_sp(ctry_name = "ALGERIA", type = "long")
prov.shape <- load_clean_prov_sp(ctry_name = "ALGERIA", type = "long")
generate_timeliness_maps(ctry.data, ctry.shape, prov.shape, "2021-01-01", "2023-12-31")
} # }