get_constant.Rd
Some links used in certain functions are hardcoded, but may change in the future. For ease of link maintenance, constants will be added to this function.
get_constant(constant_name = NULL)
str Name of the constant. Valid values include:
str
"DEFAULT_EDAV_FOLDER"
"CTRY_RISK_CAT"
"LAB_LOCATIONS"
"SIRFUNCTIONS_GITHUB_TREE"
"CLEANED_LAB_DATA"
str A string, typically a file path or a URL.
get_constant("DEFAULT_EDAV_FOLDER") #> [1] "GID/PEB/SIR"