Get the columns where records differ in a group
get_diff_cols.RdGet the columns where duplicates differ after performing a dplyr::distinct() operation.
In some instances, two records might exist with the same unique identifier. In datasets with lots of columns,
it is difficult to figure out which columns these potential duplicates differ. The function outputs the columns
where records with the same unique identifier differ.