Obtain a pins board from EDAV
get_edav_pins_board.RdThis is a convenience function to obtain a pins board in EDAV. After the pins board is loaded, several functions from the pins package are available to explore the board. Please see the pins package get started page.
Usage
get_edav_pins_board(
board_loc = "GID/PEB/SIR/pins_board",
azcontainer = get_azure_storage_connection()
)