Checks for errors in the ISS data
iss_data_errors.RdCurrently, the function reports the number of missing priority levels.
Usage
iss_data_errors(
iss_data,
error_path = Sys.getenv("DR_ERROR_PATH"),
ctry.data = lifecycle::deprecated()
)Arguments
- iss_data
tibbleISS data.- error_path
strPath to error folder. The function defaults to a global environment variable calledDR_ERROR_PATH, as it is assumed ISS data error checking is done as part of the desk review template. The setting of desk review environmental variables is automatically handled byinit_dr(). Otherwise, users should manually specify the error folder.- ctry.data
listPlease pass the ISS data directly to the iss.data parameter.
Examples
if (FALSE) { # \dontrun{
iss_path <- "C:/Users/ABC1/Desktop/iss_data.csv"
ctry.data <- init_dr("somalia", iss_data_path = iss_path)
iss_data_errors(ctry.data$iss.data)
} # }