Read ISS/eSURV data
load_iss_data.RdThe function is written to assist in load the ISS data from a path specified
by the user during init_dr(). This function is not meant to be exported.

load_iss_data.RdThe function is written to assist in load the ISS data from a path specified
by the user during init_dr(). This function is not meant to be exported.