Set the emergence colors
set_emergence_colors.RdUsed in conjunction to generate_adhoc_map(). The function returns a named
list with emergence names mapped to a color.
Usage
set_emergence_colors(
raw.data,
country,
start_date = NULL,
end_date = NULL,
get_unassigned = FALSE
)Arguments
- raw.data
listGlobal polio data output ofget_all_polio_data().- country
strorlistCountries of interest.- start_date
strStart date of the time span to look for emergences. Defaults to 13 months from the end date.- end_date
strEnd date of the time span to look for emergences Defaults to download date ofraw.data.- get_unassigned
logicalGet a list of emergence without a color mapped. This parameter is useful for ensuring that emergences are all accounted for when making a map.
Examples
if (FALSE) { # \dontrun{
raw.data <- get_all_polio_data(attach.spatial.data = FALSE)
emg.cols <- set_emergence_colors(raw.data, "algeria")
} # }