Test network connection to the EDAV
test_EDAV_connection.RdTests upload and download from EDAV by creating a temporary file of a given size and testing the time it takes to upload and download the file.
Usage
test_EDAV_connection(
azcontainer = suppressMessages(get_azure_storage_connection()),
folder = "GID/PEB/SIR/Data",
return_list = F,
test_size = 1e+07
)Arguments
- azcontainer
Azure storage container provided by
get_azure_storage_connection().- folder
strLocation of folder in the EDAV environment that you want to download and upload data from.- return_list
logicalreturn a list of download time estimates. Defaults toFALSE.- test_size
intbyte size of a theoretical file to be uploaded or downloaded.